--- old/usr/src/uts/common/inet/ip/ip.c	2012-08-18 10:37:13.245774637 +0000
+++ new/usr/src/uts/common/inet/ip/ip.c	2012-08-18 10:37:13.581747168 +0000
@@ -111,6 +111,9 @@
 #include <ipp/ipgpc/ipgpc.h>
 
 #include <sys/pattr.h>
+#include <inet/dccp.h>
+#include <inet/dccp_impl.h>
+#include <inet/dccp_ip.h>
 #include <inet/ipclassifier.h>
 #include <inet/sctp_ip.h>
 #include <inet/sctp/sctp_impl.h>
@@ -1821,6 +1824,38 @@
 		    mp->b_wptr)
 			goto truncated;
 		break;
+	case IPPROTO_DCCP: {
+		dccpha_t	*dccpha;
+
+		/*
+		 * Verify we have at least ICMP_MIN_TP_HDR_LEN bytes of
+		 * transport header.
+		 */
+		if ((uchar_t *)ipha + hdr_length + ICMP_MIN_TP_HDR_LEN >
+		    mp->b_wptr)
+			goto truncated;
+
+		cmn_err(CE_NOTE, "icmp_inbound_verify_v4");
+
+		dccpha = (dccpha_t *)((uchar_t *)ipha + hdr_length);
+		/* XXX:DCCP */
+/*
+		connp = ipcl_dccp_lookup_reversed_ipv4(ipha, dccpha,
+		    DCCPS_LISTEN, ipst);
+		if (connp == NULL) {
+			goto discard_pkt;
+		}
+
+		if ((connp->conn_verifyicmp != NULL) &&
+		    !connp->conn_verifyicmp(connp, dccpha, icmph, NULL, ira)) {
+			CONN_DEC_REF(connp);
+			goto discard_pkt;
+		}
+
+		CONN_DEC_REF(connp);
+*/
+		break;
+	}
 	case IPPROTO_ESP:
 	case IPPROTO_AH:
 		break;
@@ -2169,6 +2204,10 @@
 		ira->ira_flags &= ~IRAF_ICMP_ERROR;
 		return;
 
+	case IPPROTO_DCCP:
+		cmn_err(CE_NOTE, "icmp_inbound_error_fanout_v4");
+		return;
+
 	case IPPROTO_ESP:
 	case IPPROTO_AH:
 		if (!ipsec_loaded(ipss)) {
@@ -4311,6 +4350,7 @@
 	icmp_ddi_g_destroy();
 	rts_ddi_g_destroy();
 	udp_ddi_g_destroy();
+	dccp_ddi_g_destroy();
 	sctp_ddi_g_destroy();
 	tcp_ddi_g_destroy();
 	ilb_ddi_g_destroy();
@@ -4547,6 +4587,7 @@
 	ipsec_policy_g_init();
 	tcp_ddi_g_init();
 	sctp_ddi_g_init();
+	dccp_ddi_g_init();
 	dce_g_init();
 
 	/*
@@ -9684,9 +9725,15 @@
 	if ((mpctl = sctp_snmp_get_mib2(q, mpctl, sctps)) == NULL) {
 		return (1);
 	}
+
 	if ((mpctl = ip_snmp_get_mib2_ip_dce(q, mpctl, ipst)) == NULL) {
 		return (1);
 	}
+
+	if ((mpctl = dccp_snmp_get(q, mpctl, legacy_req)) == NULL) {
+		return (1);
+	}
+
 	freemsg(mpctl);
 	return (1);
 }
@@ -15237,6 +15284,7 @@
 		cpu_seqid = cpu[id]->cpu_seqid;
 		netstack_next_init(&nh);
 		while ((ns = netstack_next(&nh)) != NULL) {
+			dccp_stack_cpu_add(ns->netstack_dccp, cpu_seqid);
 			tcp_stack_cpu_add(ns->netstack_tcp, cpu_seqid);
 			sctp_stack_cpu_add(ns->netstack_sctp, cpu_seqid);
 			udp_stack_cpu_add(ns->netstack_udp, cpu_seqid);
